@@ -1058,6 +1058,8 @@ ADD_READ_ID:
             from_node->read_ids_n = read_ids_n;
         } else if (from_node->read_ids_n < read_ids_n) {
             from_node->read_ids = (uint64_t*)_err_realloc(from_node->read_ids, read_ids_n * sizeof(uint64_t*));
+            int i;
+            for (i = from_node->read_ids_n; i < read_ids_n; ++i) from_node->read_ids[i] = 0;
             from_node->read_ids_n = read_ids_n;
         }
         abpoa_set_read_id(from_node->read_ids, read_id);
@@ -1069,7 +1071,7 @@ void abpoa_add_graph_sequence(abpoa_graph_t *abg, uint8_t *seq, int seq_l, int s
     if (seq_l <= 0 || start >= seq_l || end <= start) err_fatal(__func__, "seq_l: %d\tstart: %d\tend: %d.", seq_l, start, end);
     if (start < 0) start = 0; if (end > seq_l) end = seq_l;
     int node_id = abpoa_add_graph_node(abg, seq[start]);
-    abpoa_add_graph_edge(abg, ABPOA_SRC_NODE_ID, node_id, 0, 1, 0, read_id, read_ids_n);
+    abpoa_add_graph_edge(abg, ABPOA_SRC_NODE_ID, node_id, 0, 1, add_read_id, read_id, read_ids_n);
     int i; 
     for (i = start+1; i < end; ++i) {
         node_id = abpoa_add_graph_node(abg, seq[i]);
